\name{tExp}
\alias{dtexp}
\alias{ptexp}
\alias{qtexp}
\alias{rtexp}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
The truncated exponential distribution
}
\description{
Density, distribution function, quantile function and random generation for the truncated exponential distribution.
}
\usage{
dtexp(x, rate = 1, endpoint = Inf, log = FALSE)
ptexp(x, rate = 1, endpoint = Inf, lower.tail = TRUE, log.p = FALSE)
qtexp(p, rate = 1, endpoint = Inf, lower.tail = TRUE, log.p = FALSE)
rtexp(n, rate = 1, endpoint = Inf)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
Vector of quantiles.
}
  \item{p}{
Vector of probabilities.
}
  \item{n}{
Number of observations.
}
  \item{rate}{
The rate parameter for the exponential distribution, default is 1.
}
  \item{endpoint}{
Endpoint of the truncated exponential distribution. The default value is \code{Inf} for which the truncated exponential distribution corresponds to the ordinary exponential distribution.
}
 \item{log}{
  Logical indicating if the densities are given as \eqn{\log(f)}, default is \code{FALSE}.
 }
 \item{lower.tail}{
 Logical indicating if the probabilities are of the form \eqn{P(X\le x)} (\code{TRUE}) or \eqn{P(X>x)} (\code{FALSE}). Default is \code{TRUE.}
 }
  \item{log.p}{
  Logical indicating if the probabilities are given as \eqn{\log(p)}, default is \code{FALSE}.
 }
}
\details{
The Cumulative Distribution Function (CDF) of the truncated exponential distribution is equal to
\eqn{F_T(x) = F(x) / F(T)} for \eqn{x \le T} where \eqn{F} is the CDF of the ordinary exponential distribution and \eqn{T} is the endpoint (truncation point) of the truncated exponential distribution.
}
\value{
\code{dtexp} gives the density function evaluated in \eqn{x}, \code{ptexp} the CDF evaluated in \eqn{x} and \code{qtexp} the quantile function evaluated in \eqn{p}. The length of the result is equal to the length of \eqn{x} or \eqn{p}.

\code{rtexp} returns a random sample of length \eqn{n}.
}

\author{
Tom Reynkens.
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link[stats]{Exponential}},  \code{\link[stats]{Distributions}}
}
\examples{
# Plot of the PDF
x <- seq(0, 10, 0.01)
plot(x, dtexp(x, rate = 2, endpoint=5), xlab="x", ylab="PDF", type="l")

# Plot of the CDF
x <- seq(0, 10, 0.01)
plot(x, ptexp(x, rate = 2, endpoint=5), xlab="x", ylab="CDF", type="l")

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{distribution}
